Changelog
=========


0.1.17 (2018-04-14)
-------------------

Fix
~~~
- Fixing python 3.2 support. [Luis Alejandro Martínez Faneyth]


0.1.16 (2018-04-14)
-------------------

Fix
~~~
- Pinning versions of software to avoid CI breaks over time. [Luis
  Alejandro Martínez Faneyth]
- Fixing PEP8 styleguide. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]
- Add Gitter badge (#29) [The Gitter Badger]


0.1.15 (2017-08-02)
-------------------

Changes
~~~~~~~
- Adding development tools to requirements. [Luis Alejandro Martínez
  Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.14 (2017-08-02)
-------------------

Changes
~~~~~~~
- Adding pyup configuration. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.13 (2017-08-02)
-------------------

Changes
~~~~~~~
- Improving parsing of requirements for setuptools. [Luis Alejandro
  Martínez Faneyth]
- Adjusting version of setuptools for python 2.6. [Luis Alejandro
  martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.12 (2017-07-17)
-------------------

Changes
~~~~~~~
- Adjusting environment markers for different python versions. [Luis
  Alejandro martínez Faneyth]
- Removing rq.filter notation. [Luis Alejandro martínez Faneyth]
- Adding support for pyup. [Luis Alejandro martínez Faneyth]
- Migrating to environment markers in requirements for simpler
  management. [Luis Alejandro martínez Faneyth]
- Improving README. [Luis Alejandro martínez Faneyth]

Fix
~~~
- Fixing pydocstyle tests. [Luis Alejandro martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro martínez Faneyth]


0.1.11 (2017-05-20)
-------------------

Fix
~~~
- Fixing python 3.5+ support. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.10 (2017-05-19)
-------------------

Fix
~~~
- Fixing python 3.2 support. [Luis Alejandro Martínez Faneyth]
- Fixing python 3.2 tests. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.9 (2017-05-19)
------------------
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.8 (2017-05-19)
------------------

Fix
~~~
- Fixing python 3.5+ support. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.7 (2017-01-16)
------------------

Fix
~~~
- Hotfix: Fixing Travis build because documentation typo. [Luis
  Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.6 (2017-01-16)
------------------

Changes
~~~~~~~
- Improving python 3 compatibility. [REF] Renaming pipsalabim.core.util
  to pipsalabim.core.utils. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.5 (2017-01-16)
------------------

Fix
~~~
- Fixing python3 compatibility. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.4 (2017-01-15)
------------------

Changes
~~~~~~~
- Fixing python 2.6 support on the logger module (closes #11). [ADD]
  Implementing functional test on .travis.yml. [Luis Alejandro Martínez
  Faneyth]

Fix
~~~
- Fixing testing for python 3.2 and 2.6. [Luis Alejandro Martínez
  Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]
- New: dev: Adding support to python 2.6 (closes #10). chg: dev:
  Removing configurations for codeclimate. [Luis Alejandro Martínez
  Faneyth]


0.1.3 (2017-01-04)
------------------

New
~~~
- Adding gitchangelog configuration file. [Luis Alejandro Martínez
  Faneyth]
- Adding support to python 2.6 (closes #10). [Luis Alejandro Martínez
  Faneyth]

Changes
~~~~~~~
- Adding new changelog entries. [Luis Alejandro Martínez Faneyth]

Fix
~~~
- Fixing testing for python 3.2 and 2.6. [Luis Alejandro Martínez
  Faneyth]
- Fixing bumpversion config. [Luis Alejandro Martínez Faneyth]
- Fixing typo. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]
- Bump version: 0.1.0 → 0.1.1. [Luis Alejandro Martínez Faneyth]


0.1.2 (2017-01-04)
------------------

New
~~~
- Adding gitchangelog configuration file. [Luis Alejandro Martínez
  Faneyth]
- Adding support to python 2.6 (closes #10). [Luis Alejandro Martínez
  Faneyth]

Other
~~~~~
- Updating Changelog and version. [Luis Alejandro Martínez Faneyth]


0.1.1 (2016-11-24)
------------------

New
~~~
- Adding Contributor License Agreement. [Luis Alejandro Martínez
  Faneyth]

Changes
~~~~~~~
- Adding new changelog entries. [Luis Alejandro Martínez Faneyth]

Fix
~~~
- Fixing bumpversion config. [Luis Alejandro Martínez Faneyth]
- Fixing typo. [Luis Alejandro Martínez Faneyth]
- Catching exceptions on package discovery as described in #3. [REF]
  Using find_packages from setuptools to discover packages. [Luis
  Alejandro Martínez Faneyth]

Other
~~~~~
- Bump version: 0.1.0 → 0.1.1. [Luis Alejandro Martínez Faneyth]


0.1.0 (2016-11-23)
------------------

Changes
~~~~~~~
- Improving README. [Luis Alejandro Martínez Faneyth]
- Improving RST markup. [Luis Alejandro Martínez Faneyth]
- Improving documentation. [REF] Configuring codeclimate. [Luis
  Alejandro Martínez Faneyth]
- Completing API documentation. [REF] Finishing commandline programming.
  [Luis Alejandro Martínez Faneyth]
- Temporarily increasing McCabe index to 20 to pass tests. [REF]
  Updating requirements versions. [REF] Improving documentation. [Luis
  Alejandro Martínez Faneyth]
- Improving documentation. [Luis Alejandro Martínez Faneyth]
- Correcting code style. [Luis Alejandro Martínez Faneyth]
- Improving documentation of functions. [REF] Porting snakefood's code
  to python 3.x. [REF] Various coe style corrections. [Luis Alejandro
  Martínez Faneyth]
- Adding code from snakefood because it doesn't support py3k. [REF]
  Fixing PEP8 errors. [Luis Alejandro Martínez Faneyth]
- Improving documentation. [REF] Adding download progress to "update"
  command. [Luis Alejandro Martínez Faneyth]
- Improving documentation. [REF] Updating visual style. [REF]
  Reorganizing code. [Luis Alejandro Martínez Faneyth]
- Updating visual style. [Luis Alejandro Martínez Faneyth]
- General refactoring of structure and code. [ADD] Adding projecto
  boilerplate. [ADD] Programming of "guess" command. [ADD] Adding visual
  style. [Luis Alejandro Martínez Faneyth]

Fix
~~~
- Correcting minor issues. [Luis Alejandro Martínez Faneyth]
- Fixing typo. [Luis Alejandro Martínez Faneyth]

Other
~~~~~
- 0.1.0 release. [Luis Alejandro Martínez Faneyth]
- Add Gitter badge. [The Gitter Badger]
- [DEL] Removing unnecessary tests. [REF] Reorganizing code. [REF]
  Documenting functions. [REF] Starting some unit tests. [Luis Alejandro
  Martínez Faneyth]
- Initial commit. [Luis Alejandro Martínez Faneyth]


